@@ -25,22 +25,22 @@ from .paginator import (
     ListVirtualClustersPaginator,
 )
 from .type_defs import (
-    CancelJobRunResponseTypeDef,
+    CancelJobRunResponseResponseTypeDef,
     ConfigurationOverridesTypeDef,
     ContainerProviderTypeDef,
-    CreateManagedEndpointResponseTypeDef,
-    CreateVirtualClusterResponseTypeDef,
-    DeleteManagedEndpointResponseTypeDef,
-    DeleteVirtualClusterResponseTypeDef,
-    DescribeJobRunResponseTypeDef,
-    DescribeManagedEndpointResponseTypeDef,
-    DescribeVirtualClusterResponseTypeDef,
+    CreateManagedEndpointResponseResponseTypeDef,
+    CreateVirtualClusterResponseResponseTypeDef,
+    DeleteManagedEndpointResponseResponseTypeDef,
+    DeleteVirtualClusterResponseResponseTypeDef,
+    DescribeJobRunResponseResponseTypeDef,
+    DescribeManagedEndpointResponseResponseTypeDef,
+    DescribeVirtualClusterResponseResponseTypeDef,
     JobDriverTypeDef,
-    ListJobRunsResponseTypeDef,
-    ListManagedEndpointsResponseTypeDef,
-    ListTagsForResourceResponseTypeDef,
-    ListVirtualClustersResponseTypeDef,
-    StartJobRunResponseTypeDef,
+    ListJobRunsResponseResponseTypeDef,
+    ListManagedEndpointsResponseResponseTypeDef,
+    ListTagsForResourceResponseResponseTypeDef,
+    ListVirtualClustersResponseResponseTypeDef,
+    StartJobRunResponseResponseTypeDef,
 )
 
 if sys.version_info >= (3, 8):
@@ -69,7 +69,7 @@ class Exceptions:
 
 class EMRContainersClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/emr-containers.html#EMRContainers.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html)
     """
 
@@ -80,15 +80,17 @@ class EMRContainersClient:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/emr-containers.html#EMRContainers.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#can_paginate)
         """
 
-    def cancel_job_run(self, *, id: str, virtualClusterId: str) -> CancelJobRunResponseTypeDef:
+    def cancel_job_run(
+        self, *, id: str, virtualClusterId: str
+    ) -> CancelJobRunResponseResponseTypeDef:
         """
         Cancels a job run.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/emr-containers.html#EMRContainers.Client.cancel_job_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.cancel_job_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#cancel_job_run)
         """
 
@@ -104,11 +106,11 @@ class EMRContainersClient:
         clientToken: str,
         configurationOverrides: "ConfigurationOverridesTypeDef" = None,
         tags: Dict[str, str] = None
-    ) -> CreateManagedEndpointResponseTypeDef:
+    ) -> CreateManagedEndpointResponseResponseTypeDef:
         """
         Creates a managed endpoint.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/emr-containers.html#EMRContainers.Client.create_managed_endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.create_managed_endpoint)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#create_managed_endpoint)
         """
 
@@ -119,55 +121,57 @@ class EMRContainersClient:
         containerProvider: "ContainerProviderTypeDef",
         clientToken: str,
         tags: Dict[str, str] = None
-    ) -> CreateVirtualClusterResponseTypeDef:
+    ) -> CreateVirtualClusterResponseResponseTypeDef:
         """
         Creates a virtual cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/emr-containers.html#EMRContainers.Client.create_virtual_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.create_virtual_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#create_virtual_cluster)
         """
 
     def delete_managed_endpoint(
         self, *, id: str, virtualClusterId: str
-    ) -> DeleteManagedEndpointResponseTypeDef:
+    ) -> DeleteManagedEndpointResponseResponseTypeDef:
         """
         Deletes a managed endpoint.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/emr-containers.html#EMRContainers.Client.delete_managed_endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.delete_managed_endpoint)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#delete_managed_endpoint)
         """
 
-    def delete_virtual_cluster(self, *, id: str) -> DeleteVirtualClusterResponseTypeDef:
+    def delete_virtual_cluster(self, *, id: str) -> DeleteVirtualClusterResponseResponseTypeDef:
         """
         Deletes a virtual cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/emr-containers.html#EMRContainers.Client.delete_virtual_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.delete_virtual_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#delete_virtual_cluster)
         """
 
-    def describe_job_run(self, *, id: str, virtualClusterId: str) -> DescribeJobRunResponseTypeDef:
+    def describe_job_run(
+        self, *, id: str, virtualClusterId: str
+    ) -> DescribeJobRunResponseResponseTypeDef:
         """
         Displays detailed information about a job run.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/emr-containers.html#EMRContainers.Client.describe_job_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.describe_job_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#describe_job_run)
         """
 
     def describe_managed_endpoint(
         self, *, id: str, virtualClusterId: str
-    ) -> DescribeManagedEndpointResponseTypeDef:
+    ) -> DescribeManagedEndpointResponseResponseTypeDef:
         """
         Displays detailed information about a managed endpoint.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/emr-containers.html#EMRContainers.Client.describe_managed_endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.describe_managed_endpoint)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#describe_managed_endpoint)
         """
 
-    def describe_virtual_cluster(self, *, id: str) -> DescribeVirtualClusterResponseTypeDef:
+    def describe_virtual_cluster(self, *, id: str) -> DescribeVirtualClusterResponseResponseTypeDef:
         """
         Displays detailed information about a specified virtual cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/emr-containers.html#EMRContainers.Client.describe_virtual_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.describe_virtual_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#describe_virtual_cluster)
         """
 
@@ -181,7 +185,7 @@ class EMRContainersClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/emr-containers.html#EMRContainers.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#generate_presigned_url)
         """
 
@@ -195,11 +199,11 @@ class EMRContainersClient:
         states: List[JobRunStateType] = None,
         maxResults: int = None,
         nextToken: str = None
-    ) -> ListJobRunsResponseTypeDef:
+    ) -> ListJobRunsResponseResponseTypeDef:
         """
         Lists job runs based on a set of parameters.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/emr-containers.html#EMRContainers.Client.list_job_runs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.list_job_runs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#list_job_runs)
         """
 
@@ -213,19 +217,21 @@ class EMRContainersClient:
         states: List[EndpointStateType] = None,
         maxResults: int = None,
         nextToken: str = None
-    ) -> ListManagedEndpointsResponseTypeDef:
+    ) -> ListManagedEndpointsResponseResponseTypeDef:
         """
         Lists managed endpoints based on a set of parameters.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/emr-containers.html#EMRContainers.Client.list_managed_endpoints)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.list_managed_endpoints)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#list_managed_endpoints)
         """
 
-    def list_tags_for_resource(self, *, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
+    def list_tags_for_resource(
+        self, *, resourceArn: str
+    ) -> ListTagsForResourceResponseResponseTypeDef:
         """
         Lists the tags assigned to the resources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/emr-containers.html#EMRContainers.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#list_tags_for_resource)
         """
 
@@ -239,11 +245,11 @@ class EMRContainersClient:
         states: List[VirtualClusterStateType] = None,
         maxResults: int = None,
         nextToken: str = None
-    ) -> ListVirtualClustersResponseTypeDef:
+    ) -> ListVirtualClustersResponseResponseTypeDef:
         """
         Lists information about the specified virtual cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/emr-containers.html#EMRContainers.Client.list_virtual_clusters)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.list_virtual_clusters)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#list_virtual_clusters)
         """
 
@@ -258,11 +264,11 @@ class EMRContainersClient:
         name: str = None,
         configurationOverrides: "ConfigurationOverridesTypeDef" = None,
         tags: Dict[str, str] = None
-    ) -> StartJobRunResponseTypeDef:
+    ) -> StartJobRunResponseResponseTypeDef:
         """
         Starts a job run.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/emr-containers.html#EMRContainers.Client.start_job_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.start_job_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#start_job_run)
         """
 
@@ -270,7 +276,7 @@ class EMRContainersClient:
         """
         Assigns tags to resources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/emr-containers.html#EMRContainers.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#tag_resource)
         """
 
@@ -278,14 +284,14 @@ class EMRContainersClient:
         """
         Removes tags from resources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/emr-containers.html#EMRContainers.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#untag_resource)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_job_runs"]) -> ListJobRunsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobRuns)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobRuns)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listjobrunspaginator)
         """
 
@@ -294,7 +300,7 @@ class EMRContainersClient:
         self, operation_name: Literal["list_managed_endpoints"]
     ) -> ListManagedEndpointsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/emr-containers.html#EMRContainers.Paginator.ListManagedEndpoints)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Paginator.ListManagedEndpoints)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listmanagedendpointspaginator)
         """
 
@@ -303,6 +309,6 @@ class EMRContainersClient:
         self, operation_name: Literal["list_virtual_clusters"]
     ) -> ListVirtualClustersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/emr-containers.html#EMRContainers.Paginator.ListVirtualClusters)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/emr-containers.html#EMRContainers.Paginator.ListVirtualClusters)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listvirtualclusterspaginator)
         """
